@@ -224,6 +224,12 @@ def run_forecast_ensemble(
         "consolidated_metrics": consolidated_metrics
     })
 
+    # Add horizon column
+    first_prediction_date = return_dataframe[DATE_COLUMN_NAME].min()
+    return_dataframe["horizon"] = return_dataframe[DATE_COLUMN_NAME].apply(
+        lambda x: relativedelta(first_prediction_date, x).years + 1
+    )
+
     # Create degraded accuracies for all models
     training_years = round((df[DATE_COLUMN_NAME].max() - df[DATE_COLUMN_NAME].min()).days / 365)
     for model in ensemble:
